@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2023
+# Copyright (C) 2015-2024
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -36,6 +36,10 @@ class InputSticker(TelegramObject):
 
     .. versionadded:: 20.2
 
+    .. versionchanged:: 21.1
+        As of Bot API 7.2, the new argument :paramref:`format` is a required argument, and thus the
+        order of the arguments has changed.
+
     Args:
         sticker (:obj:`str` | :term:`file object` | :obj:`bytes` | :class:`pathlib.Path`): The
             added sticker. |uploadinputnopath| Animated and video stickers can't be uploaded via
@@ -52,6 +56,13 @@ class InputSticker(TelegramObject):
             :tg-const:`telegram.constants.StickerLimit.MAX_KEYWORD_LENGTH` characters. For
             ":tg-const:`telegram.constants.StickerType.REGULAR`" and
             ":tg-const:`telegram.constants.StickerType.CUSTOM_EMOJI`" stickers only.
+        format (:obj:`str`): Format of the added sticker, must be one of
+            :tg-const:`telegram.constants.StickerFormat.STATIC` for a
+            ``.WEBP`` or ``.PNG`` image, :tg-const:`telegram.constants.StickerFormat.ANIMATED`
+            for a ``.TGS`` animation, :tg-const:`telegram.constants.StickerFormat.VIDEO` for a WEBM
+            video.
+
+            .. versionadded:: 21.1
 
     Attributes:
         sticker (:obj:`str` | :class:`telegram.InputFile`): The added sticker.
@@ -67,15 +78,23 @@ class InputSticker(TelegramObject):
             :tg-const:`telegram.constants.StickerLimit.MAX_KEYWORD_LENGTH` characters. For
             ":tg-const:`telegram.constants.StickerType.REGULAR`" and
             ":tg-const:`telegram.constants.StickerType.CUSTOM_EMOJI`" stickers only.
+            ":tg-const:`telegram.constants.StickerType.CUSTOM_EMOJI`" stickers only.
+        format (:obj:`str`): Format of the added sticker, must be one of
+            :tg-const:`telegram.constants.StickerFormat.STATIC` for a
+            ``.WEBP`` or ``.PNG`` image, :tg-const:`telegram.constants.StickerFormat.ANIMATED`
+            for a ``.TGS`` animation, :tg-const:`telegram.constants.StickerFormat.VIDEO` for a WEBM
+            video.
 
+            .. versionadded:: 21.1
     """
 
-    __slots__ = ("emoji_list", "keywords", "mask_position", "sticker")
+    __slots__ = ("emoji_list", "format", "keywords", "mask_position", "sticker")
 
     def __init__(
         self,
         sticker: FileInput,
         emoji_list: Sequence[str],
+        format: str,  # pylint: disable=redefined-builtin
         mask_position: Optional[MaskPosition] = None,
         keywords: Optional[Sequence[str]] = None,
         *,
@@ -91,6 +110,7 @@ class InputSticker(TelegramObject):
             attach=True,
         )
         self.emoji_list: Tuple[str, ...] = parse_sequence_arg(emoji_list)
+        self.format: str = format
         self.mask_position: Optional[MaskPosition] = mask_position
         self.keywords: Tuple[str, ...] = parse_sequence_arg(keywords)
 
