@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2023
+# Copyright (C) 2015-2024
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -21,13 +21,9 @@ from typing import TYPE_CHECKING, Optional, Sequence, Tuple
 
 from telegram._inline.inputmessagecontent import InputMessageContent
 from telegram._messageentity import MessageEntity
-from telegram._utils.argumentparsing import parse_sequence_arg
-from telegram._utils.defaultvalue import DEFAULT_NONE, DefaultValue
+from telegram._utils.argumentparsing import parse_lpo_and_dwpp, parse_sequence_arg
+from telegram._utils.defaultvalue import DEFAULT_NONE
 from telegram._utils.types import JSONDict, ODVInput
-from telegram._utils.warnings_transition import (
-    warn_about_deprecated_attr_in_property,
-    warn_for_link_preview_options,
-)
 
 if TYPE_CHECKING:
     from telegram._linkpreviewoptions import LinkPreviewOptions
@@ -54,22 +50,24 @@ class InputTextMessageContent(InputMessageContent):
             .. versionchanged:: 20.0
                 |sequenceclassargs|
 
+        link_preview_options (:obj:`LinkPreviewOptions`, optional): Link preview generation
+            options for the message. Mutually exclusive with
+            :paramref:`disable_web_page_preview`.
+
+            .. versionadded:: 20.8
+
+    Keyword Args:
         disable_web_page_preview (:obj:`bool`, optional): Disables link previews for links in the
-            sent message. Mutually exclusive with :paramref:`link_preview_options`.
+            sent message. Convenience parameter for setting :paramref:`link_preview_options`.
+            Mutually exclusive with :paramref:`link_preview_options`.
 
             .. versionchanged:: 20.8
                 Bot API 7.0 introduced :paramref:`link_preview_options` replacing this
                 argument. PTB will automatically convert this argument to that one, but
                 for advanced options, please use :paramref:`link_preview_options` directly.
 
-            .. deprecated:: 20.8
-                In future versions, this argument will become keyword only.
-
-        link_preview_options (:obj:`LinkPreviewOptions`, optional): Link preview generation
-            options for the message. Mutually exclusive with
-            :paramref:`disable_web_page_preview`.
-
-            .. versionadded:: 20.8
+            .. versionchanged:: 21.0
+                |keyword_only_arg|
 
     Attributes:
         message_text (:obj:`str`): Text of the message to be sent,
@@ -84,8 +82,7 @@ class InputTextMessageContent(InputMessageContent):
                 * |tupleclassattrs|
                 * |alwaystuple|
         link_preview_options (:obj:`LinkPreviewOptions`): Optional. Link preview generation
-            options for the message. Mutually exclusive with
-            :attr:`disable_web_page_preview`.
+            options for the message.
 
             .. versionadded:: 20.8
 
@@ -97,10 +94,10 @@ class InputTextMessageContent(InputMessageContent):
         self,
         message_text: str,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
-        disable_web_page_preview: ODVInput[bool] = DEFAULT_NONE,
         entities: Optional[Sequence[MessageEntity]] = None,
         link_preview_options: ODVInput["LinkPreviewOptions"] = DEFAULT_NONE,
         *,
+        disable_web_page_preview: Optional[bool] = None,
         api_kwargs: Optional[JSONDict] = None,
     ):
         super().__init__(api_kwargs=api_kwargs)
@@ -111,27 +108,8 @@ class InputTextMessageContent(InputMessageContent):
             # Optionals
             self.parse_mode: ODVInput[str] = parse_mode
             self.entities: Tuple[MessageEntity, ...] = parse_sequence_arg(entities)
-            self.link_preview_options: ODVInput["LinkPreviewOptions"] = (
-                warn_for_link_preview_options(disable_web_page_preview, link_preview_options)
+            self.link_preview_options: ODVInput["LinkPreviewOptions"] = parse_lpo_and_dwpp(
+                disable_web_page_preview, link_preview_options
             )
 
             self._id_attrs = (self.message_text,)
-
-    @property
-    def disable_web_page_preview(self) -> Optional[bool]:
-        """Optional[:obj:`bool`]: Disables link previews for links in the sent message.
-
-        .. deprecated:: 20.8
-        """
-        warn_about_deprecated_attr_in_property(
-            deprecated_attr_name="disable_web_page_preview",
-            new_attr_name="link_preview_options",
-            bot_api_version="7.0",
-            stacklevel=2,
-        )
-        if (
-            isinstance(self.link_preview_options, DefaultValue)
-            or self.link_preview_options is None
-        ):
-            return None
-        return bool(self.link_preview_options.is_disabled)
