@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2023
+# Copyright (C) 2015-2024
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,20 +18,12 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Telegram KeyboardButton."""
 
-from typing import TYPE_CHECKING, Optional, Union
+from typing import TYPE_CHECKING, Optional
 
 from telegram._keyboardbuttonpolltype import KeyboardButtonPollType
-from telegram._keyboardbuttonrequest import (
-    KeyboardButtonRequestChat,
-    KeyboardButtonRequestUser,
-    KeyboardButtonRequestUsers,
-)
+from telegram._keyboardbuttonrequest import KeyboardButtonRequestChat, KeyboardButtonRequestUsers
 from telegram._telegramobject import TelegramObject
 from telegram._utils.types import JSONDict
-from telegram._utils.warnings_transition import (
-    warn_about_deprecated_arg_return_new_arg,
-    warn_about_deprecated_attr_in_property,
-)
 from telegram._webappinfo import WebAppInfo
 
 if TYPE_CHECKING:
@@ -60,6 +52,8 @@ class KeyboardButton(TelegramObject):
           versions released after 3 February, 2023. Older clients will display unsupported
           message.
 
+    .. versionchanged:: 21.0
+       Removed deprecated argument and attribute ``request_user``.
     .. versionchanged:: 20.0
        :attr:`web_app` is considered as well when comparing objects of this type in terms of
        equality.
@@ -83,17 +77,10 @@ class KeyboardButton(TelegramObject):
             Available in private chats only.
 
             .. versionadded:: 20.0
-        request_user (:class:`KeyboardButtonRequestUser` | :class:`KeyboardButtonRequestUsers`, \
-            optional): Alias for
-            :attr:`request_users`.
-
-            .. versionadded:: 20.1
-            .. deprecated:: 20.8
-               Bot API 7.0 deprecates this argument in favor of ref`request_users`.
 
         request_users (:class:`KeyboardButtonRequestUsers`, optional): If specified, pressing the
             button will open a list of suitable users. Tapping on any user will send its
-            identifier to the bot in a :attr:`telegram.Message.user_shared` service message.
+            identifier to the bot in a :attr:`telegram.Message.users_shared` service message.
             Available in private chats only.
 
             .. versionadded:: 20.8
@@ -121,7 +108,7 @@ class KeyboardButton(TelegramObject):
             .. versionadded:: 20.0
         request_users (:class:`KeyboardButtonRequestUsers`): Optional. If specified, pressing the
             button will open a list of suitable users. Tapping on any user will send its
-            identifier to the bot in a :attr:`telegram.Message.user_shared` service message.
+            identifier to the bot in a :attr:`telegram.Message.users_shared` service message.
             Available in private chats only.
 
             .. versionadded:: 20.8
@@ -150,9 +137,6 @@ class KeyboardButton(TelegramObject):
         request_location: Optional[bool] = None,
         request_poll: Optional[KeyboardButtonPollType] = None,
         web_app: Optional[WebAppInfo] = None,
-        request_user: Optional[
-            Union[KeyboardButtonRequestUsers, KeyboardButtonRequestUser]
-        ] = None,
         request_chat: Optional[KeyboardButtonRequestChat] = None,
         request_users: Optional[KeyboardButtonRequestUsers] = None,
         *,
@@ -167,15 +151,7 @@ class KeyboardButton(TelegramObject):
         self.request_location: Optional[bool] = request_location
         self.request_poll: Optional[KeyboardButtonPollType] = request_poll
         self.web_app: Optional[WebAppInfo] = web_app
-        self.request_users: Optional[KeyboardButtonRequestUsers] = (
-            warn_about_deprecated_arg_return_new_arg(
-                deprecated_arg=request_user,
-                new_arg=request_users,
-                deprecated_arg_name="request_user",
-                new_arg_name="request_users",
-                bot_api_version="7.0",
-            )
-        )
+        self.request_users: Optional[KeyboardButtonRequestUsers] = request_users
         self.request_chat: Optional[KeyboardButtonRequestChat] = request_chat
 
         self._id_attrs = (
@@ -190,21 +166,6 @@ class KeyboardButton(TelegramObject):
 
         self._freeze()
 
-    @property
-    def request_user(self) -> Optional[KeyboardButtonRequestUsers]:
-        """Optional[:class:`KeyboardButtonRequestUsers`]: Alias for :attr:`request_users`.
-
-        .. versionadded:: 20.1
-        .. deprecated:: 20.8
-           Bot API 7.0 deprecates this attribute in favor of :attr:`request_users`.
-        """
-        warn_about_deprecated_attr_in_property(
-            deprecated_attr_name="request_user",
-            new_attr_name="request_users",
-            bot_api_version="7.0",
-        )
-        return self.request_users
-
     @classmethod
     def de_json(cls, data: Optional[JSONDict], bot: "Bot") -> Optional["KeyboardButton"]:
         """See :meth:`telegram.TelegramObject.de_json`."""
@@ -218,4 +179,10 @@ class KeyboardButton(TelegramObject):
         data["request_chat"] = KeyboardButtonRequestChat.de_json(data.get("request_chat"), bot)
         data["web_app"] = WebAppInfo.de_json(data.get("web_app"), bot)
 
-        return super().de_json(data=data, bot=bot)
+        api_kwargs = {}
+        # This is a deprecated field that TG still returns for backwards compatibility
+        # Let's filter it out to speed up the de-json process
+        if request_user := data.get("request_user"):
+            api_kwargs = {"request_user": request_user}
+
+        return super()._de_json(data=data, bot=bot, api_kwargs=api_kwargs)
