@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2023
+# Copyright (C) 2015-2024
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -57,7 +57,7 @@ collect_ignore = []
 if sys.version_info < (3, 10):
     if RUN_TEST_OFFICIAL:
         logging.warning("Skipping test_official.py since it requires Python 3.10+")
-    collect_ignore.append("test_official.py")
+    collect_ignore_glob = ["test_official/*.py"]
 
 
 # This is here instead of in setup.cfg due to https://github.com/pytest-dev/pytest/issues/8343
@@ -73,9 +73,7 @@ def no_rerun_after_xfail_or_flood(error, name, test: pytest.Function, plugin):
     if getattr(error[1], "msg", "") is None:
         raise error[1]
     did_we_flood = "flood" in getattr(error[1], "msg", "")  # _pytest.outcomes.XFailed has 'msg'
-    if xfail_present or did_we_flood:
-        return False
-    return True
+    return not (xfail_present or did_we_flood)
 
 
 def pytest_collection_modifyitems(items: List[pytest.Item]):
