@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2023
+# Copyright (C) 2015-2024
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -26,7 +26,6 @@ import time
 import pytest
 
 from telegram.ext import ApplicationBuilder, CallbackContext, ContextTypes, Defaults, Job, JobQueue
-from telegram.warnings import PTBUserWarning
 from tests.auxil.envvars import GITHUB_ACTION, TEST_WITH_OPT_DEPS
 from tests.auxil.pytest_classes import make_bot
 from tests.auxil.slots import mro_slots
@@ -80,11 +79,6 @@ class TestJobQueue:
     job_time = 0
     received_error = None
 
-    expected_warning = (
-        "Prior to v20.0 the `days` parameter was not aligned to that of cron's weekday scheme."
-        " We recommend double checking if the passed value is correct."
-    )
-
     async def test_repr(self, app):
         jq = JobQueue()
         jq.set_application(app)
@@ -375,20 +369,8 @@ class TestJobQueue:
         scheduled_time = job_queue.jobs()[0].next_t.timestamp()
         assert scheduled_time == pytest.approx(expected_reschedule_time)
 
-    async def test_run_daily_warning(self, job_queue, recwarn):
-        delta, now = 1, dtm.datetime.now(UTC)
-        time_of_day = (now + dtm.timedelta(seconds=delta)).time()
-
-        job_queue.run_daily(self.job_run_once, time_of_day)
-        assert len(recwarn) == 0
-        job_queue.run_daily(self.job_run_once, time_of_day, days=(0, 1, 2, 3))
-        assert len(recwarn) == 1
-        assert str(recwarn[0].message) == self.expected_warning
-        assert recwarn[0].category is PTBUserWarning
-        assert recwarn[0].filename == __file__, "wrong stacklevel"
-
     @pytest.mark.parametrize("weekday", [0, 1, 2, 3, 4, 5, 6])
-    async def test_run_daily_days_of_week(self, job_queue, recwarn, weekday):
+    async def test_run_daily_days_of_week(self, job_queue, weekday):
         delta, now = 1, dtm.datetime.now(UTC)
         time_of_day = (now + dtm.timedelta(seconds=delta)).time()
         # offset in days until next weekday
@@ -400,10 +382,6 @@ class TestJobQueue:
         await asyncio.sleep(delta + 0.1)
         scheduled_time = job_queue.jobs()[0].next_t.timestamp()
         assert scheduled_time == pytest.approx(expected_reschedule_time)
-        assert len(recwarn) == 1
-        assert str(recwarn[0].message) == self.expected_warning
-        assert recwarn[0].category is PTBUserWarning
-        assert recwarn[0].filename == __file__, "wrong stacklevel"
 
     async def test_run_monthly(self, job_queue, timezone):
         delta, now = 1, dtm.datetime.now(timezone)
