@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2023
+# Copyright (C) 2015-2024
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -149,7 +149,7 @@ class TestConstantsWithoutRequest:
 
         if any(re.match(pattern, name) for pattern in patters):
             return False
-        if name in {
+        return name not in {
             "author_signature",
             "api_kwargs",
             "caption",
@@ -176,10 +176,8 @@ class TestConstantsWithoutRequest:
             # attribute is deprecated, no need to add it to MessageType
             "user_shared",
             "via_bot",
-        }:
-            return False
-
-        return True
+            "is_from_offline",
+        }
 
     @pytest.mark.parametrize(
         "attribute",
