@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2023
+# Copyright (C) 2015-2024
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -23,11 +23,9 @@ from telegram import (
     KeyboardButton,
     KeyboardButtonPollType,
     KeyboardButtonRequestChat,
-    KeyboardButtonRequestUser,
     KeyboardButtonRequestUsers,
     WebAppInfo,
 )
-from telegram.warnings import PTBDeprecationWarning
 from tests.auxil.slots import mro_slots
 
 
@@ -82,7 +80,8 @@ class TestKeyboardButtonWithoutRequest(TestKeyboardButtonBase):
         assert keyboard_button_dict["request_chat"] == keyboard_button.request_chat.to_dict()
         assert keyboard_button_dict["request_users"] == keyboard_button.request_users.to_dict()
 
-    def test_de_json(self, bot):
+    @pytest.mark.parametrize("request_user", [True, False])
+    def test_de_json(self, bot, request_user):
         json_dict = {
             "text": self.text,
             "request_location": self.request_location,
@@ -92,45 +91,26 @@ class TestKeyboardButtonWithoutRequest(TestKeyboardButtonBase):
             "request_chat": self.request_chat.to_dict(),
             "request_users": self.request_users.to_dict(),
         }
+        if request_user:
+            json_dict["request_user"] = {"request_id": 2}
 
-        inline_keyboard_button = KeyboardButton.de_json(json_dict, None)
-        assert inline_keyboard_button.api_kwargs == {}
-        assert inline_keyboard_button.text == self.text
-        assert inline_keyboard_button.request_location == self.request_location
-        assert inline_keyboard_button.request_contact == self.request_contact
-        assert inline_keyboard_button.request_poll == self.request_poll
-        assert inline_keyboard_button.web_app == self.web_app
-        assert inline_keyboard_button.request_chat == self.request_chat
-        assert inline_keyboard_button.request_user == self.request_users
-        assert inline_keyboard_button.request_users == self.request_users
+        keyboard_button = KeyboardButton.de_json(json_dict, None)
+        if request_user:
+            assert keyboard_button.api_kwargs == {"request_user": {"request_id": 2}}
+        else:
+            assert keyboard_button.api_kwargs == {}
+
+        assert keyboard_button.text == self.text
+        assert keyboard_button.request_location == self.request_location
+        assert keyboard_button.request_contact == self.request_contact
+        assert keyboard_button.request_poll == self.request_poll
+        assert keyboard_button.web_app == self.web_app
+        assert keyboard_button.request_chat == self.request_chat
+        assert keyboard_button.request_users == self.request_users
 
         none = KeyboardButton.de_json({}, None)
         assert none is None
 
-    def test_request_user_deprecation_mutually_exclusive(self):
-        with pytest.raises(ValueError, match="'request_user' was renamed to 'request_users'"):
-            KeyboardButton(
-                "test",
-                request_users=KeyboardButtonRequestUsers(1),
-                request_user=KeyboardButtonRequestUsers(2),
-            )
-
-    def test_request_user_argument_deprecation_warning(self):
-        with pytest.warns(
-            PTBDeprecationWarning, match="'request_user' to 'request_users'"
-        ) as record:
-            KeyboardButton("test", request_user=KeyboardButtonRequestUser(2))
-
-        assert record[0].filename == __file__, "wrong stacklevel"
-
-    def test_request_user_property_deprecation_warning(self, keyboard_button):
-        with pytest.warns(
-            PTBDeprecationWarning, match="'request_user' to 'request_users'"
-        ) as record:
-            assert keyboard_button.request_user is keyboard_button.request_users
-
-        assert record[0].filename == __file__, "wrong stacklevel"
-
     def test_equality(self):
         a = KeyboardButton("test", request_contact=True)
         b = KeyboardButton("test", request_contact=True)
