@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2023
+# Copyright (C) 2015-2024
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -16,17 +16,10 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program. If not, see [http://www.gnu.org/licenses/].
-import inspect
 
 import pytest
 
-from telegram import (
-    ChatAdministratorRights,
-    KeyboardButtonRequestChat,
-    KeyboardButtonRequestUser,
-    KeyboardButtonRequestUsers,
-)
-from telegram.warnings import PTBDeprecationWarning
+from telegram import ChatAdministratorRights, KeyboardButtonRequestChat, KeyboardButtonRequestUsers
 from tests.auxil.slots import mro_slots
 
 
@@ -92,28 +85,6 @@ class TestKeyboardButtonRequestUsersWithoutRequest(TestKeyboardButtonRequestUser
         assert hash(a) != hash(c)
 
 
-class TestKeyboardButtonRequestUserWithoutRequest:
-    def test_slot_behaviour(self):
-        inst = KeyboardButtonRequestUser(1)
-        for attr in inst.__slots__:
-            assert getattr(inst, attr, "err") != "err", f"got extra slot '{attr}'"
-        assert len(mro_slots(inst)) == len(set(mro_slots(inst))), "duplicate slot"
-
-    def test_signature(self):
-        assert inspect.signature(KeyboardButtonRequestUser) == inspect.signature(
-            KeyboardButtonRequestUsers
-        )
-
-    def test_deprecation_warning(self):
-        with pytest.warns(
-            PTBDeprecationWarning,
-            match="'KeyboardButtonRequestUser' was renamed to 'KeyboardButtonRequestUsers'",
-        ) as record:
-            KeyboardButtonRequestUser(request_id=1)
-
-        assert record[0].filename == __file__, "wrong stacklevel"
-
-
 @pytest.fixture(scope="class")
 def request_chat():
     return KeyboardButtonRequestChat(
@@ -135,10 +106,30 @@ class TestKeyboardButtonRequestChatBase:
     chat_has_username = True
     chat_is_created = False
     user_administrator_rights = ChatAdministratorRights(
-        True, False, True, False, True, False, True, False
+        True,
+        False,
+        True,
+        False,
+        True,
+        False,
+        True,
+        False,
+        can_post_stories=False,
+        can_edit_stories=False,
+        can_delete_stories=False,
     )
     bot_administrator_rights = ChatAdministratorRights(
-        True, False, True, False, True, False, True, False
+        True,
+        False,
+        True,
+        False,
+        True,
+        False,
+        True,
+        False,
+        can_post_stories=False,
+        can_edit_stories=False,
+        can_delete_stories=False,
     )
     bot_is_member = True
 
